Examples of using autologging — Autologging 0.4.0 documentation

# Examples of using `autologging`

Release: | 0.4.0

- Using the `@logged` decorator
  - Add a module-named logger to a class
  - Add a user-named logger to a class
  - Add a logger to a nested class
  - Add a module-named logger to a function
  - Add a user-named logger to a function
  - Add a logger to a nested function
- Using the `TracedMethods` metaclass factory and the `@traced` decorator
  - Trace all methods of a class using a module-named logger
  - Trace all methods of a class using a user-named logger
  - Trace only certain methods of a class
  - Trace a nested class
  - Trace a function using a module-named logger
  - Trace a function using a user-named logger
  - Trace a nested function
- Using `@logged`, `TracedMethods`, and `@traced` together
  - Add logging and tracing to a class
  - Add logging and tracing to a function
- Logging, tracing, and inheritance